@@ -38,14 +38,19 @@ class QueryHelper:
                 redis_config (dict) : config arguments for redis connector
         """
         caller_locals = inspect.currentframe().f_back.f_locals
-        caller_module = caller_locals.get('__module__')
-        caller_class = caller_locals.get('__qualname__')
+        if caller_locals.get('self') is not None:
+            caller_module = caller_locals['self'].__module__
+            caller_class = caller_locals['self'].__class__.__name__
+        else:
+            caller_module = caller_locals.get('__module__')
+            caller_class = caller_locals.get('__qualname__')
+
         self.query_helper_caller = caller_module
 
         if caller_class is not None:
             self.query_helper_caller = '{caller_module}.{caller_class}'.format(
-                caller_module=caller_locals.get('__module__'),
-                caller_class=caller_locals.get('__qualname__')
+                caller_module=caller_module,
+                caller_class=caller_class
             )
 
         # get rds config
